@@ -14,6 +14,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import six
+
 from pycadf import cadftype
 
 TYPE_URI_CRED = cadftype.CADF_VERSION_1_0_0 + 'credential'
@@ -29,10 +31,10 @@ class Credential(cadftype.CADFAbstractType):
 
     type = cadftype.ValidatorDescriptor(
         CRED_KEYNAME_TYPE,
-        lambda x: isinstance(x, basestring))
+        lambda x: isinstance(x, six.string_types))
     token = cadftype.ValidatorDescriptor(
         CRED_KEYNAME_TOKEN,
-        lambda x: isinstance(x, basestring))
+        lambda x: isinstance(x, six.string_types))
 
     def __init__(self, token, type=None):
 
